pub struct OrganizationInviteLink {
pub id: Uuid,
pub code: Uuid,
pub organization_id: OrganizationId,
pub allowed_domains: Vec<String>,
pub invite: Invite,
pub supports_confirmation: bool,
pub creation_date: DateTime<Utc>,
}Expand description
An organization invite link as persisted by the server.
Fields
id: UuidUnique identifier of the invite link.
code: UuidThe invite code invitees present when accepting or confirming the invite.
organization_id: OrganizationIdThe organization this invite link belongs to.
allowed_domains: Vec<String>Email domains permitted to redeem this invite link.
invite: InviteThe sealed cryptographic invite carried in the invite link.
supports_confirmation: boolWhether invitees can self-confirm using this invite link.
creation_date: DateTime<Utc>When the invite link was created.